==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/opencl_2vector__operations_8hpp.js <==
var opencl_2vector__operations_8hpp =
[
    [ "av", "opencl_2vector__operations_8hpp.html#a03243122a1a2c45b41fb02d04ce2f21b", null ],
    [ "avbv", "opencl_2vector__operations_8hpp.html#a99e0dc95b92ed1fa56c13ec48caf9aab", null ],
    [ "avbv_v", "opencl_2vector__operations_8hpp.html#af2e502723670d95745339eedc5a4ed98", null ],
    [ "element_op", "opencl_2vector__operations_8hpp.html#abc7becb6439b83a538e28e64f005ed3b", null ],
    [ "element_op", "opencl_2vector__operations_8hpp.html#a23aad63531d04768c6d28c3f25ce64f4", null ],
    [ "index_norm_inf", "opencl_2vector__operations_8hpp.html#ae8fdcd903786ddaaf80f31ab99f6f296", null ],
    [ "inner_prod_cpu", "opencl_2vector__operations_8hpp.html#a5c62e6fe8e1151f73f2764337bb17b8f", null ],
    [ "inner_prod_impl", "opencl_2vector__operations_8hpp.html#a2aab820de0a4fb811bc09ca84b3c4e42", null ],
    [ "inner_prod_impl", "opencl_2vector__operations_8hpp.html#a5b18ba2b0fe0d7f393d99d6c0d0cc3f0", null ],
    [ "make_layout", "opencl_2vector__operations_8hpp.html#a66ecf8efa0b41147e85710db81cc9e37", null ],
    [ "max_cpu", "opencl_2vector__operations_8hpp.html#ac79bc14c508a0830434970c2cee89641", null ],
    [ "max_impl", "opencl_2vector__operations_8hpp.html#ac170765011d5fabf045d6adae0916f95", null ],
    [ "min_cpu", "opencl_2vector__operations_8hpp.html#a96c7c34e9ab708abe647c5d1eb7f6b07", null ],
    [ "min_impl", "opencl_2vector__operations_8hpp.html#a71a1b9f38905691db366f206dfea4bd5", null ],
    [ "norm_1_cpu", "opencl_2vector__operations_8hpp.html#a346e36e15039793998dd606f6e6c2543", null ],
    [ "norm_1_impl", "opencl_2vector__operations_8hpp.html#afd5fb48f2e4cbe4ecd561d8b4af424a7", null ],
    [ "norm_2_cpu", "opencl_2vector__operations_8hpp.html#ae6af79b78b4fb3986863b3d617c0362f", null ],
    [ "norm_2_impl", "opencl_2vector__operations_8hpp.html#ac01c4f0830ba78e361d84e120bbe588b", null ],
    [ "norm_inf_cpu", "opencl_2vector__operations_8hpp.html#a87adbaa14d91e0c3b0cb67b9c85f7e74", null ],
    [ "norm_inf_impl", "opencl_2vector__operations_8hpp.html#a886967c879e0ff911598d80ea2f8b1b0", null ],
    [ "plane_rotation", "opencl_2vector__operations_8hpp.html#a64046186f30c897d35ea7facef3b4c4e", null ],
    [ "vector_assign", "opencl_2vector__operations_8hpp.html#ab8cd375f30d0899d7739883bcfc37597", null ],
    [ "vector_swap", "opencl_2vector__operations_8hpp.html#af95960bfd18fd4a21c7b003c6cbaa329", null ]
];

==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/opencl_2vector__operations_8hpp.js <==
var opencl_2vector__operations_8hpp =
[
    [ "av", "opencl_2vector__operations_8hpp.html#a03243122a1a2c45b41fb02d04ce2f21b", null ],
    [ "avbv", "opencl_2vector__operations_8hpp.html#a99e0dc95b92ed1fa56c13ec48caf9aab", null ],
    [ "avbv_v", "opencl_2vector__operations_8hpp.html#af2e502723670d95745339eedc5a4ed98", null ],
    [ "convert", "opencl_2vector__operations_8hpp.html#a541e559b22fd19a7a453af6beca00b2b", null ],
    [ "element_op", "opencl_2vector__operations_8hpp.html#abc7becb6439b83a538e28e64f005ed3b", null ],
    [ "element_op", "opencl_2vector__operations_8hpp.html#a23aad63531d04768c6d28c3f25ce64f4", null ],
    [ "exclusive_scan", "opencl_2vector__operations_8hpp.html#a2ab3c5aa6788fe5dce609753f8c038f7", null ],
    [ "inclusive_scan", "opencl_2vector__operations_8hpp.html#a89a844a138804369fef44a01653e85b3", null ],
    [ "index_norm_inf", "opencl_2vector__operations_8hpp.html#ae8fdcd903786ddaaf80f31ab99f6f296", null ],
    [ "inner_prod_cpu", "opencl_2vector__operations_8hpp.html#a5c62e6fe8e1151f73f2764337bb17b8f", null ],
    [ "inner_prod_impl", "opencl_2vector__operations_8hpp.html#a2aab820de0a4fb811bc09ca84b3c4e42", null ],
    [ "inner_prod_impl", "opencl_2vector__operations_8hpp.html#a5b18ba2b0fe0d7f393d99d6c0d0cc3f0", null ],
    [ "make_layout", "opencl_2vector__operations_8hpp.html#a66ecf8efa0b41147e85710db81cc9e37", null ],
    [ "max_cpu", "opencl_2vector__operations_8hpp.html#ac79bc14c508a0830434970c2cee89641", null ],
    [ "max_impl", "opencl_2vector__operations_8hpp.html#ac170765011d5fabf045d6adae0916f95", null ],
    [ "min_cpu", "opencl_2vector__operations_8hpp.html#a96c7c34e9ab708abe647c5d1eb7f6b07", null ],
    [ "min_impl", "opencl_2vector__operations_8hpp.html#a71a1b9f38905691db366f206dfea4bd5", null ],
    [ "norm_1_cpu", "opencl_2vector__operations_8hpp.html#a346e36e15039793998dd606f6e6c2543", null ],
    [ "norm_1_impl", "opencl_2vector__operations_8hpp.html#afd5fb48f2e4cbe4ecd561d8b4af424a7", null ],
    [ "norm_2_cpu", "opencl_2vector__operations_8hpp.html#ae6af79b78b4fb3986863b3d617c0362f", null ],
    [ "norm_2_impl", "opencl_2vector__operations_8hpp.html#ac01c4f0830ba78e361d84e120bbe588b", null ],
    [ "norm_inf_cpu", "opencl_2vector__operations_8hpp.html#a87adbaa14d91e0c3b0cb67b9c85f7e74", null ],
    [ "norm_inf_impl", "opencl_2vector__operations_8hpp.html#a886967c879e0ff911598d80ea2f8b1b0", null ],
    [ "plane_rotation", "opencl_2vector__operations_8hpp.html#a64046186f30c897d35ea7facef3b4c4e", null ],
    [ "scan_impl", "opencl_2vector__operations_8hpp.html#a9900a6b53663c061cac19d0e125fe461", null ],
    [ "sum_cpu", "opencl_2vector__operations_8hpp.html#a07a0a89b0e9f73cd9f2b799e6778679b", null ],
    [ "sum_impl", "opencl_2vector__operations_8hpp.html#a73f87509090aaf15968741d501bdc260", null ],
    [ "vector_assign", "opencl_2vector__operations_8hpp.html#ab8cd375f30d0899d7739883bcfc37597", null ],
    [ "vector_swap", "opencl_2vector__operations_8hpp.html#af95960bfd18fd4a21c7b003c6cbaa329", null ]
];
